#requires -version 2.0

# Jeffery Hicks
# http://jdhitsolutions.com/blog
# follow on Twitter: http://twitter.com/JeffHicks
#
# "Those who forget to script are doomed to repeat their work."

#  ****************************************************************
#  * DO NOT USE IN A PRODUCTION ENVIRONMENT UNTIL YOU HAVE TESTED *
#  * THOROUGHLY IN A LAB ENVIRONMENT. USE AT YOUR OWN RISK.  IF   *
#  * YOU DO NOT UNDERSTAND WHAT THIS SCRIPT DOES OR HOW IT WORKS, *
#  * DO NOT USE IT OUTSIDE OF A SECURE, TEST SETTING.             *
#  ****************************************************************


Function Clear-WindowsUpdateLog {
<#
.Synopsis
Clear the Windows Update log
.Description
Clear the Windows Update log on the specified computer. This will require restarting the WUAUSERV 
service. This script use WinRM for the remote connections.

If the system is pending a reboot, you may not be able to clear the log file, even with the Windows 
Update service stopped.

This function must be run in an elevated session and supports -Whatif.
.Parameter Computername
The name of the computer to connect to. The default is the local computer. This script uses WinRM to 
manage the log on remote computers.
.Example
PS C:\> Clear-WindowsUpdateLog

Clear the Windows Update log on the local computer.
.Example
PS C:\> Clear-WindowsUpdateLog -computername serenity,quark -verbose

Clear the Windows Update log on computers Serenity and Quark.
.Link
Backup-WindowsUpdateLog
Get-WindowsUpdateLog
.Inputs
Strings for computernames
.Outputs
File Object
.Notes
 NAME:      Clear-WindowsUpdateLog
 VERSION:   1.1
 AUTHOR:    Jeffery Hicks http://jdhitsolutions.com/blog
 LASTEDIT:  8/3/2010
 
 Learn more with a copy of Windows PowerShell 2.0: TFM (SAPIEN Press 2010)
#>

[cmdletBinding(SupportsShouldProcess=$True)]

Param(
    [Parameter(Position=0,ValueFromPipeline=$True)]
    [string[]]$Computername=$env:computername
)

    Begin {
        Write-Verbose "Starting $($myinvocation.mycommand)"
        $log="$env:windir\WindowsUpdate.log"
    }

    Process {
        foreach ($computer in $computername) {
            #test connection
            Write-Verbose "Testing $($computer.toUpper())"
            if (Test-Connection -ComputerName $computer -quiet) {
                #define a scriptblock
                $sb={
                    Param([string]$log)
                    Stop-Service -Name "wuauserv"
                    Remove-Item -Path $log
                    Start-Service -Name "wuauserv" 
                    #write the new file to the pipeline
                    Get-Item -Path $log
                }    
                                  
                #if remote then use invoke-command
                if ($pscmdlet.ShouldProcess($computer)) {
                    write-host "Clearing $log on $($computer.toUpper())" -ForegroundColor Cyan
                    #check and see if this is the local computer or a remote
                    if ($computer -eq $env:computername) {
                        Write-Verbose "Executing locally"
                        &$sb $log
                    }
                    else {
                        Write-Verbose "Executing remotely: $($computer.ToUpper())"
                        Invoke-Command -ScriptBlock $sb -ComputerName $computer -ArgumentList @($log)
                    }
                }
            }
            else {
                Write-Warning "Failed to connect to $($computer.ToUpper())"
            }
        
        } #foreach
    } #process

    End {
        Write-Verbose "Ending $($myinvocation.mycommand)"
    }

} #end function


